==> swscanner_0.1.8.orig.tar.gz: swscanner-0.1.8/src/frmutils.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FRMUTILS_H
#define FRMUTILS_H

#include <qcombobox.h>
#include <qlineedit.h>
#include <qmessagebox.h>
#include <qlabel.h>
#include <qfile.h>
#include <qfiledialog.h>
#include <qtextstream.h>
#include <qprogressbar.h>
#include <qpushbutton.h>

#include <klocale.h>
#include <kiconloader.h>

#include "dlgUtils.h"
#include "shapehandler.h"

class frmUtils : public dlgUtils
{
        Q_OBJECT
private:
	
	void swlTOshp(QFile * source, QFile * dest);
	void nssTOshp(QFile * source, QFile * dest);

public:
        frmUtils(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
        ~frmUtils();
        /*$PUBLIC_FUNCTIONS$*/

public slots:
        /*$PUBLIC_SLOTS$*/
        virtual void          FindDest();
        virtual void          FindSource();
        virtual void          TypeChanged(int i);

protected:
        /*$PROTECTED_FUNCTIONS$*/

protected slots:
        /*$PROTECTED_SLOTS$*/
        virtual void          accept();

};

#endif

==> swscanner_0.2.2.orig.tar.gz: swscanner-0.2.2/src/frmutils.h <==
/***************************************************************************
 *   Copyright (C) 2004 by Ivan Forcada Atienza                            *
 *   ivan@forcada.info                                                     *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifndef FRMUTILS_H
#define FRMUTILS_H

#include <qcombobox.h>
#include <qlineedit.h>
#include <qlabel.h>
#include <qfile.h>
#include <qtextstream.h>
#include <qpushbutton.h>
#include <qstatusbar.h>
#include <qlayout.h>

#include <klocale.h>
#include <kiconloader.h>
#include <kdialogbase.h>
#include <kfiledialog.h>
#include <kapp.h>
#include <kprogress.h>
#include <kmessagebox.h>

#include "dlgUtils.h"
#include "shapehandler.h"
#include "filehandler.h"

enum fileStrings
{
	swsFile,
	swlFile,
	nsfFile,
	shpFile,
};

class frmUtils : public KDialogBase {
Q_OBJECT

	dlgUtils *	d;	// Main widget	
	QStatusBar *	status;
	QVBoxLayout *	principalLayout;

private:
	QString	getFileString(int);
	void	swlTOshp(QFile * source, QFile * dest);
	void	nsfTOshp(QFile * source, QFile * dest);

public:
        frmUtils(QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
        ~frmUtils();
        /*$PUBLIC_FUNCTIONS$*/
	
public slots:
        /*$PUBLIC_SLOTS$*/
        virtual void	FindDest();
        virtual void	FindSource();
        virtual void	originChanged(int i);
	virtual void	destinationChanged(int i);

protected:
        /*$PROTECTED_FUNCTIONS$*/

protected slots:
        /*$PROTECTED_SLOTS$*/
        virtual void          slotUser1();

};

#endif
